@@ -7,17 +7,16 @@ from discord.http import Route
 from discord.utils import DISCORD_EPOCH
 
 
-
-__all__ = (
-    'ResponseType',
-    'InteractionDataOption',
-    'InteractionData',
-    'Interaction',
-    'Type',
-    'OptionChoice',
-    'Option',
-    'SlashCommand'
-)
+__all__ = [
+    "ResponseType",
+    "InteractionDataOption",
+    "InteractionData",
+    "Interaction",
+    "Type",
+    "OptionChoice",
+    "Option",
+    "SlashCommand"
+]
 
 
 def _self_name(self):
@@ -717,7 +716,7 @@ class Option:
         choice : OptionChoice
             the choice you're going to add
         '''
-        if 'choices' not in self.__dict__:
+        if not hasattr(self, "choices"):
             self.choices = [choice]
         else:
             self.choices.append(choice)
@@ -749,12 +748,11 @@ class Option:
             'description': self.description,
             'type': self.type
         }
-        dct = self.__dict__
-        if 'required' in dct:
+        if hasattr(self, 'required'):
             payload['required'] = True
-        if 'choices' in dct:
+        if hasattr(self, 'choices'):
             payload['choices'] = [c.__dict__ for c in self.choices]
-        if 'options' in dct:
+        if hasattr(self, 'options'):
             payload['options'] = [o.to_dict() for o in self.options]
         return payload
 
