@@ -4,12 +4,47 @@ from discord.ext.commands.cooldowns import Cooldown, CooldownMapping, BucketType
 from discord.ext.commands.errors import CommandError
 from discord.errors import Forbidden
 from .interactions import Interaction, SlashCommand
-import discord as _discord
-import asyncio as _asyncio
-import datetime as _datetime
+import discord as discord
+import asyncio as asyncio
+import datetime as datetime
 import inspect, functools
 
 
+__all__ = [
+    "SlashClient",
+    "SlashCommandResponse",
+    "SlashCommandError",
+    "CheckFailure",
+    "PrivateMessageOnly",
+    "NoPrivateMessage",
+    "NotOwner",
+    "CommandOnCooldown",
+    "NotGuildOwner",
+    "MissingRole",
+    "BotMissingRole",
+    "BotMissingAnyRole",
+    "NSFWChannelRequired",
+    "MissingPermissions",
+    "BotMissingPermissions",
+    "command",
+    "check",
+    "check_any",
+    "has_role",
+    "has_any_role",
+    "bot_has_role",
+    "bot_has_any_role",
+    "has_permissions",
+    "bot_has_permissions",
+    "has_guild_permissions",
+    "bot_has_guild_permissions",
+    "dm_only",
+    "guild_only",
+    "is_owner",
+    "is_nsfw",
+    "cooldown"
+]
+
+
 #-----------------------------------+
 #              Utils                |
 #-----------------------------------+
@@ -47,7 +82,19 @@ class SlashCommandResponse:
         except AttributeError:
             cooldown = None
         finally:
-            self._buckets = CooldownMapping(cooldown)
+            if cooldown is None:
+                try:
+                    # Assuming that it's discord.py 1.7.0+
+                    self._buckets = CooldownMapping(cooldown, BucketType.default)
+                except:
+                    # discord.py <= 1.6.x
+                    try:
+                        self._buckets = CooldownMapping(cooldown)
+                    except:
+                        # Hopefully we never reach this
+                        self._buckets = None
+            elif isinstance(cooldown, CooldownMapping):
+                self._buckets = cooldown
         self.name = name
         self.func = func
         self.guild_ids = guild_ids
@@ -75,7 +122,7 @@ class SlashCommandResponse:
     def _prepare_cooldowns(self, inter):
         if self._buckets.valid:
             dt = inter.created_at
-            current = dt.replace(tzinfo=_datetime.timezone.utc).timestamp()
+            current = dt.replace(tzinfo=datetime.timezone.utc).timestamp()
             bucket = self._buckets.get_bucket(inter, current)
             retry_after = bucket.update_rate_limit(current)
             if retry_after:
@@ -231,7 +278,7 @@ def command(*args, **kwargs):
         Otherwise this command will be registered globally. Requires ``description``
     '''
     def decorator(func):
-        if not _asyncio.iscoroutinefunction(func):
+        if not asyncio.iscoroutinefunction(func):
             raise TypeError(f'<{func.__qualname__}> must be a coroutine function')
         name = kwargs.get('name', func.__name__)
         new_func = SlashCommandResponse(
@@ -316,13 +363,13 @@ def has_role(item):
     """Similar to ``commands.has_role``"""
 
     def predicate(ctx):
-        if not isinstance(ctx.channel, _discord.abc.GuildChannel):
+        if not isinstance(ctx.channel, discord.abc.GuildChannel):
             raise NoPrivateMessage()
 
         if isinstance(item, int):
-            role = _discord.utils.get(ctx.author.roles, id=item)
+            role = discord.utils.get(ctx.author.roles, id=item)
         else:
-            role = _discord.utils.get(ctx.author.roles, name=item)
+            role = discord.utils.get(ctx.author.roles, name=item)
         if role is None:
             raise MissingRole(item)
         return True
@@ -332,10 +379,10 @@ def has_role(item):
 def has_any_role(*items):
     """Similar to ``commands.has_any_role``"""
     def predicate(ctx):
-        if not isinstance(ctx.channel, _discord.abc.GuildChannel):
+        if not isinstance(ctx.channel, discord.abc.GuildChannel):
             raise NoPrivateMessage()
 
-        getter = functools.partial(_discord.utils.get, ctx.author.roles)
+        getter = functools.partial(discord.utils.get, ctx.author.roles)
         if any(getter(id=item) is not None if isinstance(item, int) else getter(name=item) is not None for item in items):
             return True
         raise MissingAnyRole(items)
@@ -347,14 +394,14 @@ def bot_has_role(item):
 
     def predicate(ctx):
         ch = ctx.channel
-        if not isinstance(ch, _discord.abc.GuildChannel):
+        if not isinstance(ch, discord.abc.GuildChannel):
             raise NoPrivateMessage()
 
         me = ch.guild.me
         if isinstance(item, int):
-            role = _discord.utils.get(me.roles, id=item)
+            role = discord.utils.get(me.roles, id=item)
         else:
-            role = _discord.utils.get(me.roles, name=item)
+            role = discord.utils.get(me.roles, name=item)
         if role is None:
             raise BotMissingRole(item)
         return True
@@ -364,11 +411,11 @@ def bot_has_any_role(*items):
     """Similar to ``commands.bot_has_any_role``"""
     def predicate(ctx):
         ch = ctx.channel
-        if not isinstance(ch, _discord.abc.GuildChannel):
+        if not isinstance(ch, discord.abc.GuildChannel):
             raise NoPrivateMessage()
 
         me = ch.guild.me
-        getter = functools.partial(_discord.utils.get, me.roles)
+        getter = functools.partial(discord.utils.get, me.roles)
         if any(getter(id=item) is not None if isinstance(item, int) else getter(name=item) is not None for item in items):
             return True
         raise BotMissingAnyRole(items)
@@ -377,7 +424,7 @@ def bot_has_any_role(*items):
 def has_permissions(**perms):
     """Similar to ``commands.has_permissions``"""
 
-    invalid = set(perms) - set(_discord.Permissions.VALID_FLAGS)
+    invalid = set(perms) - set(discord.Permissions.VALID_FLAGS)
     if invalid:
         raise TypeError('Invalid permission(s): %s' % (', '.join(invalid)))
 
@@ -397,7 +444,7 @@ def has_permissions(**perms):
 def bot_has_permissions(**perms):
     """Similar to ``commands.bot_has_permissions``"""
 
-    invalid = set(perms) - set(_discord.Permissions.VALID_FLAGS)
+    invalid = set(perms) - set(discord.Permissions.VALID_FLAGS)
     if invalid:
         raise TypeError('Invalid permission(s): %s' % (', '.join(invalid)))
 
@@ -418,7 +465,7 @@ def bot_has_permissions(**perms):
 def has_guild_permissions(**perms):
     """Similar to ``commands.has_guild_permissions``"""
 
-    invalid = set(perms) - set(_discord.Permissions.VALID_FLAGS)
+    invalid = set(perms) - set(discord.Permissions.VALID_FLAGS)
     if invalid:
         raise TypeError('Invalid permission(s): %s' % (', '.join(invalid)))
 
@@ -439,7 +486,7 @@ def has_guild_permissions(**perms):
 def bot_has_guild_permissions(**perms):
     """Similar to ``commands.bot_has_guild_permissions``"""
 
-    invalid = set(perms) - set(_discord.Permissions.VALID_FLAGS)
+    invalid = set(perms) - set(discord.Permissions.VALID_FLAGS)
     if invalid:
         raise TypeError('Invalid permission(s): %s' % (', '.join(invalid)))
 
@@ -491,14 +538,14 @@ def is_nsfw():
     """Similar to ``commands.is_nsfw``"""
     def pred(ctx):
         ch = ctx.channel
-        if ctx.guild is None or (isinstance(ch, _discord.TextChannel) and ch.is_nsfw()):
+        if ctx.guild is None or (isinstance(ch, discord.TextChannel) and ch.is_nsfw()):
             return True
         raise NSFWChannelRequired(ch)
     return check(pred)
 
 def cooldown(rate, per, type=BucketType.default):
     '''
-    A decorator that adds a cooldown to a slash-command. Similar to **_discord.py** cooldown decorator.
+    A decorator that adds a cooldown to a slash-command. Similar to **discord.py** cooldown decorator.
 
     A cooldown allows a command to only be used a specific amount
     of times in a specific time frame. These cooldowns can be based
@@ -593,7 +640,7 @@ class SlashClient:
         | ``on_ready``, ``on_auto_register``,
         | ``on_slash_command``, ``on_slash_command_error``
         '''
-        if not _asyncio.iscoroutinefunction(func):
+        if not asyncio.iscoroutinefunction(func):
             raise TypeError(f'<{func.__qualname__}> must be a coroutine function')
         name = func.__name__
         if name.startswith('on_'):
@@ -632,7 +679,7 @@ class SlashClient:
             Otherwise this command will be registered globally. Requires ``description``
         '''
         def decorator(func):
-            if not _asyncio.iscoroutinefunction(func):
+            if not asyncio.iscoroutinefunction(func):
                 raise TypeError(f'<{func.__qualname__}> must be a coroutine function')
             name = kwargs.get('name', func.__name__)
             new_func = SlashCommandResponse(
@@ -807,7 +854,7 @@ class SlashClient:
             replacement of the old data
         '''
         if not isinstance(slash_command, SlashCommand):
-            raise _discord.InvalidArgument('parameter slash_command must be SlashCommand')
+            raise discord.InvalidArgument('parameter slash_command must be SlashCommand')
         ignore_name = kwargs.get("ignore_name", False)
         r = await self.client.http.request(
             Route(
@@ -835,7 +882,7 @@ class SlashClient:
             replacement of the old data
         '''
         if not isinstance(slash_command, SlashCommand):
-            raise _discord.InvalidArgument('parameter slash_command must be SlashCommand')
+            raise discord.InvalidArgument('parameter slash_command must be SlashCommand')
         ignore_name = kwargs.get("ignore_name", False)
         r = await self.client.http.request(
             Route(
